==> neuroio-0.0.1.tar.gz: neuroio-0.0.1/neuroio/api/settings/v1.py <==
from httpx import Response

from neuroio.api.base import APIBase, APIBaseAsync
from neuroio.constants import (
    DEFAULT_EXACT_THRESHOLD,
    DEFAULT_HA_THRESHOLD,
    DEFAULT_JUNK_THRESHOLD,
)
from neuroio.utils import request_dict_processing


class Settings(APIBase):
    def get(self) -> Response:
        try:
            return self.client.get(url="/v1/settings/thresholds/")
        finally:
            self.client.close()

    def update(
        self,
        exact: float = DEFAULT_EXACT_THRESHOLD,
        ha: float = DEFAULT_HA_THRESHOLD,
        junk: float = DEFAULT_JUNK_THRESHOLD,
    ) -> Response:
        data = request_dict_processing(locals(), ["self"])

        try:
            return self.client.patch(url="/v1/settings/thresholds/", data=data)
        finally:
            self.client.close()

    def reset(self) -> Response:
        try:
            return self.client.post(url="/v1/settings/thresholds/reset/")
        finally:
            self.client.close()


class SettingsAsync(APIBaseAsync):
    async def get(self) -> Response:
        try:
            return await self.client.get(url="/v1/settings/thresholds/")
        finally:
            await self.client.aclose()

    async def update(
        self,
        exact: float = DEFAULT_EXACT_THRESHOLD,
        ha: float = DEFAULT_HA_THRESHOLD,
        junk: float = DEFAULT_JUNK_THRESHOLD,
    ) -> Response:
        data = request_dict_processing(locals(), ["self"])

        try:
            return await self.client.patch(
                url="/v1/settings/thresholds/", data=data
            )
        finally:
            await self.client.aclose()

    async def reset(self) -> Response:
        try:
            return await self.client.post(url="/v1/settings/thresholds/reset/")
        finally:
            await self.client.aclose()

==> neuroio-0.0.6.tar.gz: neuroio-0.0.6/neuroio/api/settings/v1.py <==
from httpx import Response

from neuroio.api.base import APIBase, APIBaseAsync
from neuroio.constants import (
    DEFAULT_EXACT_THRESHOLD,
    DEFAULT_HA_THRESHOLD,
    DEFAULT_JUNK_THRESHOLD,
)
from neuroio.utils import request_dict_processing


class Settings(APIBase):
    def get(self) -> Response:
        with self.get_client() as client:
            return client.get(url="/v1/settings/thresholds/")

    def update(
        self,
        exact: float = DEFAULT_EXACT_THRESHOLD,
        ha: float = DEFAULT_HA_THRESHOLD,
        junk: float = DEFAULT_JUNK_THRESHOLD,
    ) -> Response:
        data = request_dict_processing(locals(), ["self"])

        with self.get_client() as client:
            return client.patch(url="/v1/settings/thresholds/", data=data)

    def reset(self) -> Response:
        with self.get_client() as client:
            return client.post(url="/v1/settings/thresholds/reset/")


class SettingsAsync(APIBaseAsync):
    async def get(self) -> Response:
        async with self.get_client() as client:
            return await client.get(url="/v1/settings/thresholds/")

    async def update(
        self,
        exact: float = DEFAULT_EXACT_THRESHOLD,
        ha: float = DEFAULT_HA_THRESHOLD,
        junk: float = DEFAULT_JUNK_THRESHOLD,
    ) -> Response:
        data = request_dict_processing(locals(), ["self"])

        async with self.get_client() as client:
            return await client.patch(
                url="/v1/settings/thresholds/", data=data
            )

    async def reset(self) -> Response:
        async with self.get_client() as client:
            return await client.post(url="/v1/settings/thresholds/reset/")
